@@ -58,6 +58,8 @@ class Likelihood(AnalysisObject):
             self.poi.setVal(poi_val)
             fit_status_uncond = self.minimizer.minimize()
             muhat     = self.poi.getVal()
+            muhat_errolo = self.poi.getErrorLo()
+            muhat_errohi = self.poi.getErrorHi()
             nll_uncond = self.minimizer.nll.getVal()
         fit_time_uncond = time.time() - start_time
         # conditional nll
@@ -77,6 +79,8 @@ class Likelihood(AnalysisObject):
             self.stdout.info("\tmu hat = {:.5f}\n\tuncond NLL = {:.5f}".format(muhat, nll_uncond))
             fit_result['uncond_fit'] = {
                 'muhat': muhat,
+                'muhat_errlo': muhat_errolo,
+                'muhat_errhi': muhat_errohi,
                 'nll': nll_uncond,
                 'status': fit_status_uncond,
                 'time': fit_time_uncond
